@@ -131,6 +131,12 @@ class InputChannel(object):
             )
         )
 
+    def is_socketio_channel(self):
+        return False
+
+    async def disconnect_session(self):
+        pass
+
     def get_output_channel(self) -> Optional["OutputChannel"]:
         """Create ``OutputChannel`` based on information provided by the input channel.
         Implementing this function is not required. If this function returns a valid
@@ -143,17 +149,17 @@ class InputChannel(object):
         """
         pass
 
-    async def startTracking(self, channelUserId, channel, sid):
+    async def startTracking(self, usg_msg, csi, channel, sid):
         # make IDP request here and append guid to message
         host = environ["IDENTITY_PROVIDER_HOST"]
         port = environ["IDENTITY_PROVIDER_PORT"]
 
         headers = {"Conversation-Id": sid}
         params = {
-            "CSI": channelUserId,
+            "CSI": csi,
             "channel": channel
         }
-        resp = None
+        msg = usg_msg
         try:
             async with aiohttp.ClientSession() as session:
                 async with session.get(
@@ -162,11 +168,19 @@ class InputChannel(object):
                         headers=headers,
                         timeout=3,
                 ) as res:
-                    resp = await res.text()
+                    resp = await res.json()
+
+                    # Reformat the initial string
+                    if resp.get('guid'):
+                        resp['channelUserId'] = csi
+                        msg = "/greet" + json.dumps(resp)
+                        logger.info(f"[{sid}] - User tracked by IDP with GUID. Message: {msg}")
+                    else:
+                        logger.warning(f"[{sid}] - Unable to retrieve guid from IDP: {resp}")
         except Exception as exp:
             traceback_msg = traceback.format_exc().replace("\n", "")
             logger.error(f"[{sid}] - Failed to get guid: {traceback_msg}")
-        return resp
+        return msg
 
 
 class OutputChannel(object):
