@@ -12,3 +12,5 @@ from rasa.core.policies.sklearn_policy import SklearnPolicy
 from rasa.core.policies.form_policy import FormPolicy
 from rasa.core.policies.two_stage_fallback import TwoStageFallbackPolicy
 from rasa.core.policies.mapping_policy import MappingPolicy
+from rasa.core.policies.form_nlu_fallback import FormFallbackPolicy
+from rasa.core.policies.asr_fallback import AsrFallbackPolicy
