@@ -45,6 +45,7 @@ from rasa.core.policies.form_nlu_fallback import FormFallbackPolicy
 from rasa.core.tracker_store import TrackerStore
 from rasa.core.trackers import DialogueStateTracker, EventVerbosity
 from rasa.utils.endpoints import EndpointConfig
+from rasa.utils.timer import timeit
 
 logger = logging.getLogger(__name__)
 
@@ -93,7 +94,7 @@ class MessageProcessor(object):
 
         await self._predict_and_execute_next_action(message, tracker)
         # save tracker state to continue conversation from this state
-        await self._save_tracker(tracker)
+        self._save_tracker(tracker)
 
         if isinstance(message.output_channel, CollectingOutputChannel):
             return message.output_channel.messages
@@ -104,7 +105,7 @@ class MessageProcessor(object):
 
         # we have a Tracker instance for each user
         # which maintains conversation state
-        tracker = await self._get_tracker(sender_id)
+        tracker = self._get_tracker(sender_id)
         if not tracker:
             logger.warning(
                 "Failed to retrieve or create tracker for sender "
@@ -114,7 +115,7 @@ class MessageProcessor(object):
 
         probabilities, policy = self._get_next_action_probabilities(tracker)
         # save tracker state to continue conversation from this state
-        await self._save_tracker(tracker)
+        self._save_tracker(tracker)
         scores = [
             {"action": a, "score": p}
             for a, p in zip(self.domain.action_names, probabilities)
@@ -133,11 +134,11 @@ class MessageProcessor(object):
             message.text = self.message_preprocessor(message.text)
         # we have a Tracker instance for each user
         # which maintains conversation state
-        tracker = await self._get_tracker(message.sender_id)
+        tracker = self._get_tracker(message.sender_id)
         if tracker:
             await self._handle_message_with_tracker(message, tracker)
             # save tracker state to continue conversation from this state
-            await self._save_tracker(tracker)
+            self._save_tracker(tracker)
         else:
             logger.warning(
                 "Failed to retrieve or create tracker for sender "
@@ -157,7 +158,7 @@ class MessageProcessor(object):
 
         # we have a Tracker instance for each user
         # which maintains conversation state
-        tracker = await self._get_tracker(sender_id)
+        tracker = self._get_tracker(sender_id)
         if tracker:
             action = self._get_action(action_name)
             await self._run_action(
@@ -165,7 +166,7 @@ class MessageProcessor(object):
             )
 
             # save tracker state to continue conversation from this state
-            await self._save_tracker(tracker)
+            self._save_tracker(tracker)
         else:
             logger.warning(
                 "Failed to retrieve or create tracker for sender "
@@ -181,19 +182,18 @@ class MessageProcessor(object):
         This should be overwritten by more advanced policies to use
         ML to predict the action. Returns the index of the next action."""
 
-        with opentracing.tracer.start_active_span('core_predict_next_action') as scope:
-            action_confidences, policy = self._get_next_action_probabilities(tracker)
+        action_confidences, policy = self._get_next_action_probabilities(tracker)
 
-            max_confidence_index = int(np.argmax(action_confidences))
-            action = self.domain.action_for_index(
-                max_confidence_index, self.action_endpoint
+        max_confidence_index = int(np.argmax(action_confidences))
+        action = self.domain.action_for_index(
+            max_confidence_index, self.action_endpoint
+        )
+        logger.info(
+            "[{}] - Predicted next action '{}' with confidence {:.2f}.".format(
+                tracker.sender_id, action.name(), action_confidences[max_confidence_index]
             )
-            logger.debug(
-                "Predicted next action '{}' with confidence {:.2f}.".format(
-                    action.name(), action_confidences[max_confidence_index]
-                )
-            )
-            return action, policy, action_confidences[max_confidence_index]
+        )
+        return action, policy, action_confidences[max_confidence_index]
 
     @staticmethod
     def _is_reminder(e: Event, name: Text) -> bool:
@@ -232,7 +232,7 @@ class MessageProcessor(object):
     ) -> None:
         """Handle a reminder that is triggered asynchronously."""
 
-        tracker = await self._get_tracker(sender_id)
+        tracker = self._get_tracker(sender_id)
 
         if not tracker:
             logger.warning(
@@ -264,7 +264,7 @@ class MessageProcessor(object):
                 user_msg = UserMessage(None, output_channel, sender_id)
                 await self._predict_and_execute_next_action(user_msg, tracker)
             # save tracker state to continue conversation from this state
-            await self._save_tracker(tracker)
+            self._save_tracker(tracker)
 
     @staticmethod
     def _log_slots(tracker):
@@ -273,7 +273,7 @@ class MessageProcessor(object):
             ["\t{}: {}".format(s.name, s.value) for s in tracker.slots.values()]
         )
         if slot_values.strip():
-            logger.debug("Current slot values: \n{}".format(slot_values))
+            logger.debug("[{}] - Current slot values: \n{}".format(tracker.sender_id, slot_values))
 
     def _is_nlu_threshold_passed(self, nlu_data, tracker):
         if self.policy_ensemble is None or tracker.active_form:
@@ -302,9 +302,9 @@ class MessageProcessor(object):
             parse_data = await self.interpreter.parse(message.text, message.message_id)
 
         logger.debug(
-            "Received user message '{}' with intent '{}' "
+            "[{}] - Received user message '{}' with intent '{}' "
             "and entities '{}'".format(
-                message.text, parse_data["intent"], parse_data["entities"]
+                message.sender_id, message.text, parse_data["intent"], parse_data["entities"]
             )
         )
         return parse_data
@@ -313,7 +313,11 @@ class MessageProcessor(object):
             self, message: UserMessage, tracker: DialogueStateTracker
     ) -> Dict:
         requested_slot = tracker.get_slot("requested_slot")
-        metadata = {"type": "user_response"}
+
+        if message.metadata and message.metadata.get("replyType"):
+            metadata = {"type": message.metadata.get("replyType")}
+        else:
+            metadata = {"type": "text"}
 
         if tracker.active_form.get("name"):
             metadata["active_form"] = tracker.active_form.get("name")
@@ -321,14 +325,22 @@ class MessageProcessor(object):
         if requested_slot:
             metadata["requested_slot"] = requested_slot
 
-            if requested_slot == "pass":
+            if requested_slot.startswith("confidential"):
                 metadata["is_pii"] = True
+
+            if requested_slot == "confidential_pass":
                 metadata["type"] = "password"
             elif requested_slot == "id":
                 metadata["type"] = "username"
 
         return metadata
 
+    def log_user_msg(self, message: UserMessage, tracker: DialogueStateTracker):
+        if message.metadata.get('is_pii'):
+            logger.info(f"[{tracker.sender_id}] - User msg: [FILTERED]")
+        else:
+            logger.info(f"[{tracker.sender_id}] - User msg: {message.text}")
+
     async def _handle_message_with_tracker(
         self, message: UserMessage, tracker: DialogueStateTracker
     ) -> None:
@@ -339,11 +351,8 @@ class MessageProcessor(object):
             parse_data = await self._parse_message(message)
 
         missed_intent = not self._is_nlu_threshold_passed(parse_data, tracker)
-
-        if message.metadata:
-            message.metadata.update(self.create_metadata(message, tracker))
-        else:
-            message.metadata = self.create_metadata(message, tracker)
+        message.metadata = self.create_metadata(message, tracker)
+        self.log_user_msg(message, tracker)
 
         # don't ever directly mutate the tracker
         # - instead pass its events to log
@@ -365,7 +374,7 @@ class MessageProcessor(object):
 
         if self._is_goodbye_msg_callback_received(tracker) and tracker.get_slot('outcome') != 'Transfer':
             outcome = "Disconnected"
-            if tracker.get_latest_input_channel().startswith('OMNI_VOICE'):
+            if tracker.get_latest_input_channel() and tracker.get_latest_input_channel().startswith('OMNI_VOICE'):
                 outcome = "Hangup"
 
             evt = {
@@ -380,8 +389,8 @@ class MessageProcessor(object):
             self._log_slots(tracker)
 
         logger.debug(
-            "Logged UserUtterance - "
-            "tracker now has {} events".format(len(tracker.events))
+            "[{}] - Logged UserUtterance - "
+            "tracker now has {} events".format(tracker.sender_id, len(tracker.events))
         )
 
     @staticmethod
@@ -395,43 +404,48 @@ class MessageProcessor(object):
     def _is_goodbye_msg_callback_received(tracker):
         return tracker.current_state().get('latest_message').get('text') == '/goodbye'
 
+    @timeit
     async def _predict_and_execute_next_action(
         self, message: UserMessage, tracker: DialogueStateTracker
     ):
-        with opentracing.tracer.start_active_span('_predict_and_execute_next_action') as scope:
-            # keep taking actions decided by the policy until it chooses to 'listen'
-            should_predict_another_action = True and not self._is_goodbye_msg_callback_received(tracker)
-            num_predicted_actions = 0
+        # keep taking actions decided by the policy until it chooses to 'listen'
+        should_predict_another_action = True and not self._is_goodbye_msg_callback_received(tracker)
+        num_predicted_actions = 0
 
-            def is_action_limit_reached():
-                return (
-                    num_predicted_actions == self.max_number_of_predictions
-                    and should_predict_another_action
-                )
+        def is_action_limit_reached():
+            return (
+                num_predicted_actions == self.max_number_of_predictions
+                and should_predict_another_action
+            )
 
-            # action loop. predicts actions until we hit action listen
-            while (
-                should_predict_another_action
-                and self._should_handle_message(tracker)
-                and num_predicted_actions < self.max_number_of_predictions
-            ):
-                # this actually just calls the policy's method by the same name
-                action, policy, confidence = self.predict_next_action(tracker)
+        # action loop. predicts actions until we hit action listen
+        start = time.time()
+        while (
+            should_predict_another_action
+            and self._should_handle_message(tracker)
+            and num_predicted_actions < self.max_number_of_predictions
+        ):
+            # this actually just calls the policy's method by the same name
+            action, policy, confidence = self.predict_next_action(tracker)
 
-                should_predict_another_action = await self._run_action(
-                    action, tracker, message.output_channel, self.nlg, policy, confidence
-                )
-                num_predicted_actions += 1
+            should_predict_another_action = await self._run_action(
+                action, tracker, message.output_channel, self.nlg, policy, confidence
+            )
+            num_predicted_actions += 1
 
-            if is_action_limit_reached():
-                # circuit breaker was tripped
-                logger.warning(
-                    "Circuit breaker tripped. Stopped predicting "
-                    "more actions for sender '{}'".format(tracker.sender_id)
-                )
-                if self.on_circuit_break:
-                    # call a registered callback
-                    self.on_circuit_break(tracker, message.output_channel, self.nlg)
+        run_time = round((time.time() - start) * 1000, 2)
+        if run_time > 500:
+            logger.warning(f"Action prediction loop finished in {run_time}ms, num of predicted actions: {num_predicted_actions}")
+
+        if is_action_limit_reached():
+            # circuit breaker was tripped
+            logger.warning(
+                "Circuit breaker tripped. Stopped predicting "
+                "more actions for sender '{}'".format(tracker.sender_id)
+            )
+            if self.on_circuit_break:
+                # call a registered callback
+                self.on_circuit_break(tracker, message.output_channel, self.nlg)
 
     # noinspection PyUnusedLocal
     @staticmethod
@@ -440,18 +454,18 @@ class MessageProcessor(object):
         return not is_listen_action
 
     @staticmethod
+    @timeit
     async def _send_bot_messages(
         events: List[Event],
         tracker: DialogueStateTracker,
         output_channel: OutputChannel,
     ) -> None:
         """Send all the bot messages that are logged in the events array."""
-        with opentracing.tracer.start_active_span('_send_bot_messages') as scope:
-            for e in events:
-                if not isinstance(e, BotUttered):
-                    continue
+        for e in events:
+            if not isinstance(e, BotUttered):
+                continue
 
-                await output_channel.send_response(tracker.sender_id, e.message())
+            await output_channel.send_response(tracker.sender_id, e.message())
 
     async def _schedule_reminders(
         self,
@@ -464,65 +478,63 @@ class MessageProcessor(object):
 
         Reminders with the same `id` property will overwrite one another
         (i.e. only one of them will eventually run)."""
-        with opentracing.tracer.start_active_span('_schedule_reminders') as scope:
-            for e in events:
-                if not isinstance(e, ReminderScheduled):
-                    continue
+        for e in events:
+            if not isinstance(e, ReminderScheduled):
+                continue
 
-                (await jobs.scheduler()).add_job(
-                    self.handle_reminder,
-                    "date",
-                    run_date=e.trigger_date_time,
-                    args=[e, tracker.sender_id, output_channel, nlg],
-                    id=e.name,
-                    replace_existing=True,
-                    name=(
-                        str(e.action_name)
-                        + ACTION_NAME_SENDER_ID_CONNECTOR_STR
-                        + tracker.sender_id
-                    ),
-                )
+            (await jobs.scheduler()).add_job(
+                self.handle_reminder,
+                "date",
+                run_date=e.trigger_date_time,
+                args=[e, tracker.sender_id, output_channel, nlg],
+                id=e.name,
+                replace_existing=True,
+                name=(
+                    str(e.action_name)
+                    + ACTION_NAME_SENDER_ID_CONNECTOR_STR
+                    + tracker.sender_id
+                ),
+            )
 
     @staticmethod
     async def _cancel_reminders(
         events: List[Event], tracker: DialogueStateTracker
     ) -> None:
         """Cancel reminders by action_name"""
-        with opentracing.tracer.start_active_span('_cancel_reminders') as scope:
-            # All Reminders with the same action name will be cancelled
-            for e in events:
-                if isinstance(e, ReminderCancelled):
-                    name_to_check = (
-                        str(e.action_name)
-                        + ACTION_NAME_SENDER_ID_CONNECTOR_STR
-                        + tracker.sender_id
-                    )
-                    scheduler = await jobs.scheduler()
-                    for j in scheduler.get_jobs():
-                        if j.name == name_to_check:
-                            scheduler.remove_job(j.id)
+        # All Reminders with the same action name will be cancelled
+        for e in events:
+            if isinstance(e, ReminderCancelled):
+                name_to_check = (
+                    str(e.action_name)
+                    + ACTION_NAME_SENDER_ID_CONNECTOR_STR
+                    + tracker.sender_id
+                )
+                scheduler = await jobs.scheduler()
+                for j in scheduler.get_jobs():
+                    if j.name == name_to_check:
+                        scheduler.remove_job(j.id)
 
+    @timeit
     async def _run_action(
         self, action, tracker, output_channel, nlg, policy=None, confidence=None
     ):
         # events and return values are used to update
         # the tracker state after an action has been taken
-        with opentracing.tracer.start_active_span('_run_action') as scope:
-            try:
-                events = await action.run(output_channel, nlg, tracker, self.domain)
-            except ActionExecutionRejection:
-                events = [ActionExecutionRejected(action.name(), policy, confidence)]
-                tracker.update(events[0])
-                return self.should_predict_another_action(action.name(), events)
-            except Exception as e:
-                logger.error(
-                    "Encountered an exception while running action '{}'. "
-                    "Bot will continue, but the actions events are lost. "
-                    "Please check the logs of your action server for "
-                    "more information.".format(action.name())
-                )
-                logger.debug(e, exc_info=True)
-                events = []
+        try:
+            events = await action.run(output_channel, nlg, tracker, self.domain)
+        except ActionExecutionRejection:
+            events = [ActionExecutionRejected(action.name(), policy, confidence)]
+            tracker.update(events[0])
+            return self.should_predict_another_action(action.name(), events)
+        except Exception as e:
+            logger.error(
+                "Encountered an exception while running action '{}'. "
+                "Bot will continue, but the actions events are lost. "
+                "Please check the logs of your action server for "
+                "more information.".format(action.name())
+            )
+            logger.debug(e, exc_info=True)
+            events = []
 
         self._log_action_on_tracker(tracker, action.name(), events, policy, confidence)
         if action.name() != ACTION_LISTEN_NAME and not action.name().startswith(
@@ -573,6 +585,7 @@ class MessageProcessor(object):
         if events is None:
             events = []
 
+        start = time.time()
         logger.debug(
             "Action '{}' ended with events '{}'".format(
                 action_name, ["{}".format(e) for e in events]
@@ -592,13 +605,16 @@ class MessageProcessor(object):
             # of the action executed
             e.timestamp = time.time()
             tracker.update(e, self.domain)
+        duration = round((time.time() - start) * 1000, 2)
+        if duration > 500:
+            logger.warning(f"Function _log_action_on_tracker took {duration}ms")
 
-    async def _get_tracker(self, sender_id: Text) -> Optional[DialogueStateTracker]:
+    def _get_tracker(self, sender_id: Text) -> Optional[DialogueStateTracker]:
         sender_id = sender_id or UserMessage.DEFAULT_SENDER_ID
-        return await self.tracker_store.get_or_create_tracker(sender_id)
+        return self.tracker_store.get_or_create_tracker(sender_id)
 
-    async def _save_tracker(self, tracker):
-        await self.tracker_store.save(tracker)
+    def _save_tracker(self, tracker):
+        self.tracker_store.save(tracker)
 
     def _prob_array_for_action(
         self, action_name: Text
