@@ -587,7 +587,7 @@ class EmbeddingIntentClassifier(Component):
         # transform sim to python list for JSON serializing
         return intent_ids, message_sim.tolist()
 
-    def process(self, message: "Message", **kwargs: Any) -> None:
+    async def process(self, message: "Message", **kwargs: Any) -> None:
         """Return the most likely intent and its similarity to the input."""
 
         intent = {"name": None, "confidence": 0.0}
