@@ -276,7 +276,7 @@ class Component(object, metaclass=ComponentMetaclass):
         of components previous to this one."""
         pass
 
-    def process(self, message: Message, **kwargs: Any) -> None:
+    async def process(self, message: Message, **kwargs: Any) -> None:
         """Process an incoming message.
 
         This is the components chance to process an incoming
