@@ -1,7 +1,10 @@
+import asyncio
 import time
 
 import logging
 import os
+
+import aiohttp
 import requests
 from typing import Any, List, Optional, Text, Dict
 
@@ -104,7 +107,7 @@ class DucklingHTTPExtractor(EntityExtractor):
             "reftime": reference_time,
         }
 
-    def _duckling_parse(self, text, reference_time):
+    async def _duckling_parse(self, text, reference_time):
         """Sends the request to the duckling server and parses the result."""
 
         try:
@@ -112,19 +115,21 @@ class DucklingHTTPExtractor(EntityExtractor):
             headers = {
                 "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8"
             }
-            response = requests.post(
-                self._url() + "/parse", data=payload, headers=headers
-            )
-            if response.status_code == 200:
-                return response.json()
-            else:
-                logger.error(
-                    "Failed to get a proper response from remote "
-                    "duckling. Status Code: {}. Response: {}"
-                    "".format(response.status_code, response.text)
-                )
-                return []
-        except requests.exceptions.ConnectionError as e:
+            async with aiohttp.ClientSession() as session:
+                async with session.post(self._url() + "/parse", data=payload, headers=headers, timeout=3) as response:
+                    if response.status == 200:
+                        return await response.json()
+                    else:
+                        logger.error(
+                            "Failed to get a proper response from remote "
+                            "duckling. Status Code: {}. Response: {}"
+                            "".format(response.status, response.text)
+                        )
+                        return []
+        except (
+                asyncio.CancelledError,
+                asyncio.TimeoutError
+        ) as e:
             logger.error(
                 "Failed to connect to duckling http server. Make sure "
                 "the duckling server is running and the proper host "
@@ -152,11 +157,11 @@ class DucklingHTTPExtractor(EntityExtractor):
         # requires the reftime in miliseconds
         return int(time.time()) * 1000
 
-    def process(self, message: Message, **kwargs: Any) -> None:
+    async def process(self, message: Message, **kwargs: Any) -> None:
 
         if self._url() is not None:
             reference_time = self._reference_time_from_message(message)
-            matches = self._duckling_parse(message.text, reference_time)
+            matches = await self._duckling_parse(message.text, reference_time)
             all_extracted = convert_duckling_format_to_rasa(matches)
             dimensions = self.component_config["dimensions"]
             extracted = DucklingHTTPExtractor.filter_irrelevant_entities(
