@@ -18,11 +18,11 @@ def run_cmdline(model_path, component_builder=None):
     while True:
         print_success("Next message:")
         message = input().strip()
+        loop = asyncio.get_event_loop()
         if message.startswith(INTENT_MESSAGE_PREFIX):
-            loop = asyncio.get_event_loop()
             result = loop.run_until_complete(regex_interpreter.parse(message))
         else:
-            result = interpreter.parse(message)
+            result = loop.run_until_complete(interpreter.parse(message))
 
         print (json_to_string(result))
 
