@@ -190,8 +190,8 @@ def event_verbosity_parameter(
         )
 
 
-async def obtain_tracker_store(agent: "Agent", conversation_id: Text) -> DialogueStateTracker:
-    tracker = await agent.tracker_store.get_or_create_tracker(conversation_id)
+def obtain_tracker_store(agent: "Agent", conversation_id: Text) -> DialogueStateTracker:
+    tracker = agent.tracker_store.get_or_create_tracker(conversation_id)
     if not tracker:
         raise ErrorResponse(
             409,
@@ -335,12 +335,6 @@ def create_app(
         # initialize_tracer('hydra')
         app.session = aiohttp.ClientSession()
 
-    @app.listener('before_server_stop')
-    async def close_session(app, loop):
-        logger.info("Shutting down Sanic server now...")
-
-        if app.session:
-            await app.session.close()
 
     @app.exception(ErrorResponse)
     async def handle_error_response(request: Request, exception: ErrorResponse):
@@ -366,17 +360,17 @@ def create_app(
     @app.get("/healthz/live")
     async def live(request: Request):
         """Check if the server is running and responds with the version."""
-        timeout = 10
+        timeout = 30
 
         try:
             if endpoints.tracker_store:
-                resp = await asyncio.wait_for(app.agent.tracker_store.test_conn(), timeout=timeout)
+                resp = app.agent.tracker_store.test_conn()
 
                 if not resp:
                     logger.error({"event": "HEALTH_CHECK", "message": "Dialog Manager is down."})
                     raise ErrorResponse(500, "ServerError", "Dialog Manager is not alive")
 
-            logger.info({"event": "HEALTH_CHECK", "message": "Dialog Manager is up and running."})
+            logger.debug({"event": "HEALTH_CHECK", "message": "Dialog Manager is up and running."})
             return response.json({"status": "ok"})
         except ErrorResponse as ex:
             logger.error({"event": "HEALTH_CHECK", "message": ex})
@@ -389,7 +383,7 @@ def create_app(
     @app.get("/healthz/ready")
     async def ready(request: Request):
         """Check if the server is running and responds with the version."""
-        timeout = 10
+        timeout = 30
         action_resp, duckling_resp = None, None
         _broker = app.agent.tracker_store.event_broker
 
@@ -411,7 +405,7 @@ def create_app(
             elif duckling_resp and duckling_resp.status != 200:
                 raise ErrorResponse(500, "DucklingServerError", "Duckling server is not ready yet.")
 
-            logger.info({"event": "HEALTH_CHECK", "message": "Dialog Manager is ready."})
+            logger.debug({"event": "HEALTH_CHECK", "message": "Dialog Manager is ready."})
             return response.json({"status": "ok"})
         except Exception as ex:
             traceback_msg = traceback.format_exc().replace("\n", "")
@@ -419,11 +413,11 @@ def create_app(
             logger.error({"event": "HEALTH_CHECK", "message": err_msg})
             raise ErrorResponse(500, "ServerError", err_msg)
 
-    @app.route("/metrics", methods=["GET", "OPTIONS"])
-    async def metrics(request):
-        registry = CollectorRegistry()
-        multiprocess.MultiProcessCollector(registry)
-        return response.text(generate_latest(registry).decode("utf-8"))
+    # @app.route("/metrics", methods=["GET", "OPTIONS"])
+    # async def metrics(request):
+    #     registry = CollectorRegistry()
+    #     multiprocess.MultiProcessCollector(registry)
+    #     return response.text(generate_latest(registry).decode("utf-8"))
 
     @app.get("/status")
     @requires_auth(app, auth_token)
@@ -455,7 +449,7 @@ def create_app(
         verbosity = event_verbosity_parameter(request, EventVerbosity.AFTER_RESTART)
         until_time = rasa.utils.endpoints.float_arg(request, "until")
 
-        tracker = await obtain_tracker_store(app.agent, conversation_id)
+        tracker = obtain_tracker_store(app.agent, conversation_id)
 
         try:
             if until_time is not None:
@@ -502,13 +496,13 @@ def create_app(
             )
 
         verbosity = event_verbosity_parameter(request, EventVerbosity.AFTER_RESTART)
-        tracker = await obtain_tracker_store(app.agent, conversation_id)
+        tracker = obtain_tracker_store(app.agent, conversation_id)
 
         try:
             for event in events:
                 tracker.update(event, app.agent.domain)
 
-            await app.agent.tracker_store.save(tracker)
+            app.agent.tracker_store.save(tracker)
 
             return response.json(tracker.current_state(verbosity))
         except Exception as e:
@@ -538,7 +532,7 @@ def create_app(
             )
 
             # will override an existing tracker with the same id!
-            await app.agent.tracker_store.save(tracker)
+            app.agent.tracker_store.save(tracker)
             return response.json(tracker.current_state(verbosity))
         except Exception as e:
             logger.debug(traceback.format_exc())
@@ -563,7 +557,7 @@ def create_app(
             )
 
         # retrieve tracker and set to requested state
-        tracker = await obtain_tracker_store(app.agent, conversation_id)
+        tracker = obtain_tracker_store(app.agent, conversation_id)
 
         until_time = rasa.utils.endpoints.float_arg(request, "until")
 
@@ -603,7 +597,7 @@ def create_app(
         verbosity = event_verbosity_parameter(request, EventVerbosity.AFTER_RESTART)
 
         try:
-            tracker = await obtain_tracker_store(app.agent, conversation_id)
+            tracker = obtain_tracker_store(app.agent, conversation_id)
             output_channel = _get_output_channel(request, tracker)
             await app.agent.execute_action(
                 conversation_id, action_to_execute, output_channel, policy, confidence
@@ -616,7 +610,7 @@ def create_app(
                 "An unexpected error occurred. Error: {}".format(e),
             )
 
-        tracker = await obtain_tracker_store(app.agent, conversation_id)
+        tracker = obtain_tracker_store(app.agent, conversation_id)
         state = tracker.current_state(verbosity)
 
         response_body = {"tracker": state}
@@ -831,7 +825,7 @@ def create_app(
         _, nlu_model = get_model_subdirectories(model_directory)
 
         try:
-            evaluation = run_evaluation(data_path, nlu_model)
+            evaluation = await run_evaluation(data_path, nlu_model)
             return response.json(evaluation)
         except Exception as e:
             logger.debug(traceback.format_exc())
@@ -949,7 +943,7 @@ def create_app(
             raise ErrorResponse(
                 500, "ParsingError", "An unexpected error occurred. Error: {}".format(e)
             )
-    
+
     @app.post("/model/parseList")
     @requires_auth(app, auth_token)
     async def parseList(request: Request):
@@ -967,12 +961,12 @@ def create_app(
                 phrase_list.append({'text': phrase, 'time': None})
             try:
                 predList = []
-                for phrase in phrase_list:    
+                for phrase in phrase_list:
                     parsed_data = await app.agent.parse_message_using_nlu_interpreter(
                         phrase['text']
                     )
                     predList.append(parsed_data)
-                
+
             except Exception as e:
                 logger.debug(traceback.format_exc())
                 raise ErrorResponse(
