@@ -20,13 +20,13 @@ def test_dialogue_serialisation(filename):
 
 
 @pytest.mark.parametrize("pair", zip(TEST_DIALOGUES, EXAMPLE_DOMAINS))
-async def test_inmemory_tracker_store(pair):
+def test_inmemory_tracker_store(pair):
     filename, domainpath = pair
     domain = Domain.load(domainpath)
     tracker = tracker_from_dialogue_file(filename, domain)
     tracker_store = InMemoryTrackerStore(domain)
-    await tracker_store.save(tracker)
-    restored = await tracker_store.retrieve(tracker.sender_id)
+    tracker_store.save(tracker)
+    restored = tracker_store.retrieve(tracker.sender_id)
     assert restored == tracker
 
 
