@@ -15,25 +15,25 @@ from tests.core.conftest import DEFAULT_ENDPOINTS_FILE
 domain = Domain.load("data/test_domains/default.yml")
 
 
-async def test_get_or_create():
+def test_get_or_create():
     slot_key = "location"
     slot_val = "Easter Island"
     store = InMemoryTrackerStore(domain)
 
-    tracker = await store.get_or_create_tracker(UserMessage.DEFAULT_SENDER_ID)
+    tracker = store.get_or_create_tracker(UserMessage.DEFAULT_SENDER_ID)
     ev = SlotSet(slot_key, slot_val)
     tracker.update(ev)
     assert tracker.get_slot(slot_key) == slot_val
 
-    await store.save(tracker)
+    store.save(tracker)
 
-    again = await store.get_or_create_tracker(UserMessage.DEFAULT_SENDER_ID)
+    again = store.get_or_create_tracker(UserMessage.DEFAULT_SENDER_ID)
     assert again.get_slot(slot_key) == slot_val
 
 
-async def test_restart_after_retrieval_from_tracker_store(default_domain):
+def test_restart_after_retrieval_from_tracker_store(default_domain):
     store = InMemoryTrackerStore(default_domain)
-    tr = await store.get_or_create_tracker("myuser")
+    tr = store.get_or_create_tracker("myuser")
     synth = [ActionExecuted("action_listen") for _ in range(4)]
 
     for e in synth:
@@ -42,23 +42,23 @@ async def test_restart_after_retrieval_from_tracker_store(default_domain):
     tr.update(Restarted())
     latest_restart = tr.idx_after_latest_restart()
 
-    await store.save(tr)
-    tr2 = await store.retrieve("myuser")
+    store.save(tr)
+    tr2 = store.retrieve("myuser")
     latest_restart_after_loading = tr2.idx_after_latest_restart()
     assert latest_restart == latest_restart_after_loading
 
 
-async def test_tracker_store_remembers_max_history(default_domain):
+def test_tracker_store_remembers_max_history(default_domain):
     store = InMemoryTrackerStore(default_domain)
-    tr = await store.get_or_create_tracker("myuser", max_event_history=42)
+    tr = store.get_or_create_tracker("myuser", max_event_history=42)
     tr.update(Restarted())
 
-    await store.save(tr)
-    tr2 = await store.retrieve("myuser")
+    store.save(tr)
+    tr2 = store.retrieve("myuser")
     assert tr._max_event_history == tr2._max_event_history == 42
 
 
-async def test_tracker_store_endpoint_config_loading():
+def test_tracker_store_endpoint_config_loading():
     cfg = read_endpoint_config(DEFAULT_ENDPOINTS_FILE, "tracker_store")
 
     assert cfg == EndpointConfig.from_dict(
