@@ -2,6 +2,7 @@
 import asyncio
 
 import responses
+from aioresponses import aioresponses
 
 from rasa.nlu.config import RasaNLUModelConfig
 from rasa.nlu.training_data import TrainingData, Message
@@ -147,12 +148,11 @@ def test_crf_json_from_non_BILOU(spacy_nlp, ner_crf_pos_feature_config):
     assert rs[4] == {"start": 29, "end": 31, "value": "by", "entity": "where"}
 
 
-def test_duckling_entity_extractor(component_builder):
-    with responses.RequestsMock() as rsps:
-        rsps.add(
-            responses.POST,
+async def test_duckling_entity_extractor(component_builder):
+    with aioresponses() as mocked:
+        mocked.post(
             "http://localhost:8000/parse",
-            json=[
+            payload=[
                 {
                     "body": "Today",
                     "start": 0,
@@ -249,7 +249,7 @@ def test_duckling_entity_extractor(component_builder):
                     "dim": "time",
                     "latent": False,
                 },
-            ],
+            ]
         )
 
         _config = RasaNLUModelConfig({"pipeline": [{"name": "DucklingHTTPExtractor"}]})
@@ -258,17 +258,16 @@ def test_duckling_entity_extractor(component_builder):
         )
         duckling = component_builder.create_component(_config.for_component(0), _config)
         message = Message("Today is the 5th of May. Let us meet tomorrow.")
-        duckling.process(message)
+        await duckling.process(message)
         entities = message.get("entities")
         assert len(entities) == 4
 
     # Test duckling with a defined date
 
-    with responses.RequestsMock() as rsps:
-        rsps.add(
-            responses.POST,
+    with aioresponses() as mocked:
+        mocked.post(
             "http://localhost:8000/parse",
-            json=[
+            payload=[
                 {
                     "body": "tomorrow",
                     "start": 12,
@@ -288,12 +287,12 @@ def test_duckling_entity_extractor(component_builder):
                     "dim": "time",
                     "latent": False,
                 }
-            ],
+            ]
         )
 
         # 1381536182 == 2013/10/12 02:03:02
         message = Message("Let us meet tomorrow.", time="1381536182")
-        duckling.process(message)
+        await duckling.process(message)
         entities = message.get("entities")
         assert len(entities) == 1
         assert entities[0]["text"] == "tomorrow"
@@ -308,11 +307,10 @@ def test_duckling_entity_extractor(component_builder):
             _config.for_component(0), _config
         )
 
-    with responses.RequestsMock() as rsps:
-        rsps.add(
-            responses.POST,
+    with aioresponses() as mocked:
+        mocked.post(
             "http://localhost:8000/parse",
-            json=[
+            payload=[
                 {
                     "body": "Yesterday",
                     "start": 0,
@@ -338,11 +336,11 @@ def test_duckling_entity_extractor(component_builder):
                     "end": 22,
                     "dim": "number",
                 },
-            ],
+            ]
         )
 
         message = Message("Yesterday there were 5 people in a room")
-        duckling_number.process(message)
+        await duckling_number.process(message)
         entities = message.get("entities")
 
         assert len(entities) == 1
@@ -363,7 +361,7 @@ def test_duckling_entity_extractor_and_synonyms(component_builder):
     duckling = component_builder.create_component(_config.for_component(0), _config)
     synonyms = component_builder.create_component(_config.for_component(1), _config)
     message = Message("He was 6 feet away")
-    duckling.process(message)
+    asyncio.get_event_loop().run_until_complete(duckling.process(message))
     # checks that the synonym processor
     # can handle entities that have int values
     synonyms.process(message)
@@ -410,7 +408,7 @@ def test_spacy_ner_extractor(component_builder, spacy_nlp):
         },
     )
 
-    ext.process(example, spacy_nlp=spacy_nlp)
+    asyncio.get_event_loop().run_until_complete(ext.process(example, spacy_nlp=spacy_nlp))
 
     assert len(example.get("entities", [])) == 1
     assert example.get("entities")[0] == {
@@ -436,7 +434,7 @@ def test_spacy_ner_extractor(component_builder, spacy_nlp):
 
     _config.set_component_attr(0, dimensions=["PERSON"])
     ext = component_builder.create_component(_config.for_component(0), _config)
-    ext.process(example, spacy_nlp=spacy_nlp)
+    asyncio.get_event_loop().run_until_complete(ext.process(example, spacy_nlp=spacy_nlp))
 
     assert len(example.get("entities", [])) == 1
     assert example.get("entities")[0] == {
