@@ -106,7 +106,7 @@ async def test_whitespace_with_case():
     component_config = {"case_sensitive": False}
     tk = WhitespaceTokenizer(component_config)
     message = Message("Forecast for LUNCH")
-    tk.process(message)
+    await tk.process(message)
     assert message.data.get("tokens")[0].text == "forecast"
     assert message.data.get("tokens")[1].text == "for"
     assert message.data.get("tokens")[2].text == "lunch"
